@@ -3,12 +3,14 @@ package main
 import (
 	"context"
 	"fmt"
-	"github.com/skupperproject/skupper/pkg/network"
-	"github.com/skupperproject/skupper/pkg/utils"
 	"reflect"
 	"strings"
 	"time"
 
+	"github.com/skupperproject/skupper/pkg/network"
+	"github.com/skupperproject/skupper/pkg/utils"
+	"github.com/skupperproject/skupper/pkg/utils/formatter"
+
 	"github.com/skupperproject/skupper/api/types"
 	"github.com/spf13/cobra"
 )
@@ -34,7 +36,7 @@ func (s *SkupperKubeSite) Create(cmd *cobra.Command, args []string) error {
 	routerIngressFlag := cmd.Flag("ingress")
 	routerCreateOpts.Platform = s.kube.Platform()
 
-	if !routerIngressFlag.Changed {
+	if !routerIngressFlag.Changed || routerCreateOpts.Ingress == "" {
 		routerCreateOpts.Ingress = cli.GetIngressDefault()
 	}
 	if routerCreateOpts.Ingress == types.IngressNodePortString && routerCreateOpts.IngressHost == "" && routerCreateOpts.Router.IngressHost == "" {
@@ -137,7 +139,7 @@ func (s *SkupperKubeSite) CreateFlags(cmd *cobra.Command) {
 	cmd.Flags().BoolVarP(&routerCreateOpts.CreateNetworkPolicy, "create-network-policy", "", false, "Create network policy to restrict access to skupper services exposed through this site to current pods in namespace")
 	cmd.Flags().StringVarP(&routerCreateOpts.AuthMode, "console-auth", "", "internal", "Authentication mode for console(s). One of: 'openshift', 'internal', 'unsecured'")
 	cmd.Flags().StringVarP(&routerCreateOpts.User, "console-user", "", "", "Skupper console user. Valid only when --console-auth=internal")
-	cmd.Flags().StringVarP(&routerCreateOpts.Password, "console-password", "", "", "Skupper console user. Valid only when --console-auth=internal")
+	cmd.Flags().StringVarP(&routerCreateOpts.Password, "console-password", "", "", "Skupper console password. Valid only when --console-auth=internal")
 	cmd.Flags().StringVarP(&routerCreateOpts.ConsoleIngress, "console-ingress", "", "", "Determines if/how console is exposed outside cluster. If not specified uses value of --ingress. One of: ["+strings.Join(types.ValidIngressOptions(s.kube.Platform()), "|")+"].")
 	cmd.Flags().BoolVarP(&routerCreateOpts.EnableRestAPI, "enable-rest-api", "", false, "Enable REST API")
 	cmd.Flags().StringSliceVar(&s.kubeInit.ingressAnnotations, "ingress-annotations", []string{}, "Annotations to add to skupper ingress")
@@ -244,7 +246,10 @@ func (s *SkupperKubeSite) Status(cmd *cobra.Command, args []string) error {
 
 	currentStatus, errStatus := cli.NetworkStatus(context.Background())
 	if errStatus != nil && strings.HasPrefix(errStatus.Error(), "Skupper is not installed") {
-		fmt.Printf("Skupper is not enabled in namespace '%s'", cli.GetNamespace())
+		fmt.Printf("Skupper is not enabled in namespace '%s'\n", cli.GetNamespace())
+		return nil
+	} else if errStatus != nil && errStatus.Error() == "status not ready" {
+		fmt.Println("Status pending...")
 		return nil
 	} else if errStatus != nil {
 		return errStatus
@@ -261,6 +266,11 @@ func (s *SkupperKubeSite) Status(cmd *cobra.Command, args []string) error {
 		return nil
 	}
 
+	localServices, err := cli.ServiceInterfaceList(context.Background())
+	if err != nil {
+		return err
+	}
+
 	var currentSite = statusManager.GetSiteById(siteConfig.Reference.UID)
 
 	if currentSite != nil {
@@ -269,11 +279,11 @@ func (s *SkupperKubeSite) Status(cmd *cobra.Command, args []string) error {
 		if len(currentSite.RouterStatus) > 0 {
 			routerMode = currentSite.RouterStatus[0].Router.Mode
 
-			statusDataOutput := StatusData{
-				enabledIn: PlatformSupport{"kubernetes", currentSite.Site.Namespace},
-				mode:      routerMode,
-				siteName:  currentSite.Site.Name,
-				policies:  currentSite.Site.Policy,
+			statusDataOutput := formatter.StatusData{
+				EnabledIn: formatter.PlatformSupport{"kubernetes", currentSite.Site.Namespace},
+				Mode:      routerMode,
+				SiteName:  currentSite.Site.Name,
+				Policies:  currentSite.Site.Policy,
 			}
 
 			err, index := statusManager.GetRouterIndex(currentSite)
@@ -281,17 +291,17 @@ func (s *SkupperKubeSite) Status(cmd *cobra.Command, args []string) error {
 				return err
 			}
 
-			mapSiteLink := statusManager.GetSiteLinkMapPerRouter(&currentSite.RouterStatus[index], &currentSite.Site)
-
+			peerSites := statusManager.GetPeerSites(&currentSite.RouterStatus[index], currentSite.Site.Identity)
 			totalSites := len(currentStatus.SiteStatus)
+
 			// the current site does not count as a connection
 			connections := totalSites - 1
-			directConnections := len(mapSiteLink)
-			statusDataOutput.totalConnections = connections
-			statusDataOutput.directConnections = directConnections
-			statusDataOutput.indirectConnections = connections - directConnections
+			directConnections := len(peerSites)
+			statusDataOutput.TotalConnections = connections
+			statusDataOutput.DirectConnections = directConnections
+			statusDataOutput.IndirectConnections = connections - directConnections
 
-			statusDataOutput.exposedServices = len(currentStatus.Addresses)
+			statusDataOutput.ExposedServices = len(localServices)
 
 			consoleUrl, _ := cli.GetConsoleUrl(cli.GetNamespace())
 
@@ -300,21 +310,21 @@ func (s *SkupperKubeSite) Status(cmd *cobra.Command, args []string) error {
 				return err
 			} else {
 				if siteConfig.Spec.EnableFlowCollector && consoleUrl != "" {
-					statusDataOutput.consoleUrl = consoleUrl
+					statusDataOutput.ConsoleUrl = consoleUrl
 					if siteConfig.Spec.AuthMode == "internal" {
-						statusDataOutput.credentials = PlatformSupport{"secret", "'skupper-console-users'"}
+						statusDataOutput.Credentials = formatter.PlatformSupport{"secret", "'skupper-console-users'"}
 					}
 				}
 			}
 
 			if err == nil && verboseStatus {
-				err := PrintVerboseStatus(statusDataOutput)
+				err := formatter.PrintVerboseStatus(statusDataOutput)
 				if err != nil {
 					return err
 				}
 
 			} else if err == nil {
-				err := PrintStatus(statusDataOutput)
+				err := formatter.PrintStatus(statusDataOutput)
 				if err != nil {
 					return err
 				}
@@ -341,7 +351,7 @@ func (s *SkupperKubeSite) Update(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	if updated {
-		fmt.Println("Skupper is now updated in '" + cli.GetNamespace() + "'.")
+		fmt.Println("Skupper update in progress for '" + cli.GetNamespace() + "'.")
 	} else {
 		fmt.Println("No update required in '" + cli.GetNamespace() + "'.")
 	}
