@@ -809,8 +809,38 @@ func (fc *FlowCollector) updateRecord(record interface{}) error {
 				}
 			} else {
 				if link.EndTime > 0 {
+					// find and delete the corresponding link for the peer router
+					if currentParentRouter, ok := fc.Routers[current.Parent]; ok {
+						if current.Direction != nil && current.Name != nil && currentParentRouter.Name != nil {
+							var peerRouterId string
+							peerDirection := Outgoing
+							if *current.Direction == Outgoing {
+								peerDirection = Incoming
+							}
+							for _, router := range fc.Routers {
+								if router.Name != nil && *current.Name == normalizeRouterName(*router.Name) {
+									peerRouterId = router.Identity
+									break
+								}
+							}
+							for _, eLink := range fc.Links {
+								if eLink.Direction != nil && *eLink.Direction == peerDirection && eLink.Parent == peerRouterId && eLink.Name != nil && *eLink.Name == normalizeRouterName(*currentParentRouter.Name) {
+									eLink.EndTime = link.EndTime
+									fc.deleteRecord(eLink)
+									break
+								}
+							}
+						}
+					}
 					current.EndTime = link.EndTime
 					fc.deleteRecord(current)
+				} else {
+					if current.LinkCost == nil && link.LinkCost != nil {
+						current.LinkCost = link.LinkCost
+						if fc.mode == RecordStatus {
+							fc.updateNetworkStatus()
+						}
+					}
 				}
 			}
 			fc.updateLastHeard(link.Source)
